@@ -12,6 +12,7 @@ from django.db.models import Count,Sum,Q
 
 from picklefield.fields import PickledObjectField
 import caching.base
+
 # Create your models here.
 
 
@@ -83,8 +84,6 @@ class Speaker(models.Model):
     F2center = models.FloatField(blank=True,null=True)
     AvgSpeakingRate = models.FloatField(blank=True,null=True)
 
-    objects = caching.base.CachingManager()
-
     def __unicode__(self):
         return u'%s' % (self.Number,)
 
@@ -169,8 +168,6 @@ class Dialog(models.Model):
     Speaker = models.ForeignKey(Speaker)
     Number = models.CharField(max_length=10)
 
-    objects = caching.base.CachingManager()
-
     def __unicode__(self):
         return u'%s%s' % (self.Speaker,self.Number)
 
@@ -230,8 +227,6 @@ class SegmentType(models.Model):
     Nasal = models.BooleanField()
     Vowel = models.BooleanField()
 
-    objects = caching.base.CachingManager()
-
     def isSyllabic(self):
         return self.Syllabic
 
@@ -258,8 +253,6 @@ class Underlying(models.Model):
     Ordering = models.IntegerField()
     Stressed = models.IntegerField(blank=True,null=True)
 
-    objects = caching.base.CachingManager()
-
     def getStrTrans(self):
         if self.Stressed is None:
             return str(self.SegmentType).upper()
@@ -275,7 +268,7 @@ class SegmentToken(models.Model):
     End = models.FloatField()
     Stressed = models.NullBooleanField()
 
-    objects = caching.base.CachingManager()
+    objects = STManager()
 
     def __unicode__(self):
         return u'%s' % unicode(self.SegmentType)
@@ -291,8 +284,6 @@ class Category(models.Model):
     Description = models.CharField(max_length=250)
     CategoryType = models.CharField('Category type',max_length=100)
 
-    objects = caching.base.CachingManager()
-
     def isContent(self):
         if self.CategoryType == 'Content':
             return True
@@ -307,8 +298,6 @@ class PrevCondProbs(models.Model):
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
-    objects = caching.base.CachingManager()
-
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
@@ -327,8 +316,6 @@ class FollCondProbs(models.Model):
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
-    objects = caching.base.CachingManager()
-
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
@@ -354,8 +341,6 @@ class WordType(models.Model):
     CVSkel = models.CharField(max_length=100,blank=True,null=True)
     StressVowel = models.CharField(max_length=10,blank=True,null=True)
 
-    objects = caching.base.CachingManager()
-
     def __unicode__(self):
         return u'%s' % self.Label
 
@@ -523,7 +508,7 @@ class WordType(models.Model):
         self.save()
 
 
-class WordToken(models.Model):
+class WordToken(caching.base.CachingMixin,models.Model):
     SR = models.ManyToManyField(SegmentType,through=SegmentToken)
     Begin = models.FloatField()
     End = models.FloatField()
